@@ -2,7 +2,7 @@ package Zonemaster::LDNS;
 
 use 5.014;
 
-our $VERSION = '1.0.2';
+our $VERSION = '2.2.1';
 
 use parent 'Exporter';
 our @EXPORT_OK = qw[to_idn has_idn ldns_version load_zonefile];
@@ -18,7 +18,7 @@ use Zonemaster::LDNS::Packet;
 
 =head1 NAME
 
-    Zonemaster::LDNS - DNS-talking module based on the ldns C library
+Zonemaster::LDNS - Perl wrapper for the ldns DNS library.
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,9 @@ Returns the ldns version string. Can be exported, but is not by default.
 
 =item to_idn($name, ...)
 
-Takes a number of strings and returns a list of them converted to IDNA format.
+Takes a number of domain names (in string format) and returns them with all
+labels converted to A-labels unless they are already in ASCII.
+
 Assumes that the strings have been converted to Perl's internal encoding before
 it's called. Can be exported, but is not by default.
 
@@ -83,6 +85,10 @@ make up a list of servers to send queries to. If an argument cannot be parsed as
 Send a query for the given triple. If type or class are not provided they default to A and IN, respectively. Returns a L<Zonemaster::LDNS::Packet> or
 undef.
 
+=item query_with_pkt($packet)
+
+Send a L<Zonemaster::LDNS::Packet>. Returns a L<Zonemaster::LDNS::Packet> or undef.
+
 =item name2addr($name)
 
 Asks this resolver to look up A and AAAA records for the given name, and return a list of the IP addresses (as strings). In scalar context, returns
@@ -112,6 +118,10 @@ Get and optionally sets the CD flag.
 
 Get and optionally sets the igntc flag.
 
+=item fallback($flag)
+
+Get and optionally sets the fallback flag.
+
 =item usevc($flag)
 
 Get and optionally sets the usevc flag.
@@ -191,3 +201,22 @@ Get and/or set the socket timeout for the resolver.
 Get and/or set the IP address the resolver should try to send its queries from.
 
 =back
+
+=head1 AUTHORS
+
+Mattias P <mattias.paivarinta@iis.se>
+- Current maintainer
+
+Calle Dybedahl <calle@init.se>
+- Original author
+
+=head1 LICENSE
+
+This is free software, licensed under:
+
+The (three-clause) BSD License
+
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
+=cut
